==> haskell-chell-quickcheck-0.2.5.4-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-CkUVBNfjuIuCbaA9kINDSe
key:                  chell-quickcheck-0.2.5.4-CkUVBNfjuIuCbaA9kINDSe
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  70b4971f2c1e5ba8aea434fde61ef09c
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-CkUVBNfjuIuCbaA9kINDSe
depends:
    QuickCheck-2.15.0.1-DUSZjYYOgXECqf7Svaitv8 base-4.17.2.1
    chell-0.5.0.2-E1vaa39ghvwHAvmrW5J7dq
    random-1.2.1.3-53eBMyqCn4j5j5sTN6ACJa

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.4-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-xF1fKQGCKm5U0mB43HrYi
key:                  chell-quickcheck-0.2.5.4-xF1fKQGCKm5U0mB43HrYi
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  3109d00c8aa6989417906de7ca4a6fb3
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-xF1fKQGCKm5U0mB43HrYi
depends:
    QuickCheck-2.15.0.1-3xlJoVjdvgVJR3Okie7O9R base-4.17.2.1
    chell-0.5.0.2-K4HSeLvX5Th7iv6ZiY0CjJ
    random-1.2.1.3-9Bk1Rk8uHFTJVqAMIpxjnc

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
